@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw/Module::Install::Base/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;
 
 sub authority {
@@ -23,7 +23,7 @@ Module::Install::Authority - Add an x_authority key to META.yml
     use inc::Module::Install;
     name 'Example';
     all_from 'lib/Example.pm'
-    authority 'BOBTFISH';
+    authority 'cpan:BOBTFISH';
     WriteAll;
 
 =head1 DESCRIPTION
